@@ -7,7 +7,7 @@
 # Authors:
 # - Daniel Drizhuk, d.drizhuk@gmail.com, 2017
 # - Mario Lassnig, mario.lassnig@cern.ch, 2017
-# - Paul Nilsson, paul.nilsson@cern.ch, 2017
+# - Paul Nilsson, paul.nilsson@cern.ch, 2017-2020
 
 import collections
 import subprocess  # Python 2/3
@@ -31,12 +31,19 @@ import pipes
 
 from .filehandling import write_file
 from .auxiliary import is_python3
+from .config import config
+from .constants import get_pilot_version
 
 import logging
 logger = logging.getLogger(__name__)
 
 _ctx = collections.namedtuple('_ctx', 'ssl_context user_agent capath cacert')
 
+# anisyonk: public copy of `_ctx` to avoid logic break since ssl_context is reset inside the request() -- FIXME
+# anisyonk: public instance, should be properly initialized by `https_setup()`
+# anisyonk: use lightweight class definition instead of namedtuple since tuple is immutable and we don't need/use any tuple features here
+ctx = type('ctx', (object,), dict(ssl_context=None, user_agent='Pilot2 client', capath=None, cacert=None))
+
 
 def _tester(func, *args):
     """
@@ -112,7 +119,7 @@ def cacert(args=None):
                    cacert_default_location())
 
 
-def https_setup(args, version):
+def https_setup(args=None, version=None):
     """
     Sets up the context for future HTTPS requests:
 
@@ -123,6 +130,9 @@ def https_setup(args, version):
     :param args: arguments, parsed by `argparse`
     :param str version: pilot version string (for :mailheader:`User-Agent`)
     """
+
+    version = version or get_pilot_version()
+
     _ctx.user_agent = 'pilot/%s (Python %s; %s %s)' % (version,
                                                        sys.version.split()[0],
                                                        platform.system(),
@@ -132,7 +142,7 @@ def https_setup(args, version):
     _ctx.capath = capath(args)
     _ctx.cacert = cacert(args)
 
-    if sys.version_info < (2, 7, 9):
+    if sys.version_info < (2, 7, 9):  # by anisyonk: actually SSL context should work, but prior to 2.7.9 there is no automatic hostname/certificate validation
         logger.warn('Python version <2.7.9 lacks SSL contexts -- falling back to curl')
         _ctx.ssl_context = None
     else:
@@ -143,6 +153,17 @@ def https_setup(args, version):
             logger.warn('SSL communication is impossible due to SSL error: %s -- falling back to curl' % str(e))
             _ctx.ssl_context = None
 
+    # anisyonk: clone `_ctx` to avoid logic break since ssl_context is reset inside the request() -- FIXME
+    ctx.capath = _ctx.capath
+    ctx.cacert = _ctx.cacert
+    ctx.user_agent = _ctx.user_agent
+
+    try:
+        ctx.ssl_context = ssl.create_default_context(capath=ctx.capath, cafile=ctx.cacert)
+        ctx.ssl_context.load_cert_chain(ctx.cacert)
+    except Exception as e:  # redandant try-catch protection, should work well for both python2 & python3 -- CLEAN ME later (anisyonk)
+        logger.warn('Failed to initialize SSL context .. skipped, error: %s' % str(e))
+
 
 def request(url, data=None, plain=False, secure=True):  # noqa: C901
     """
@@ -201,7 +222,7 @@ def request(url, data=None, plain=False, secure=True):  # noqa: C901
     if _ctx.ssl_context is None and secure:
         req = 'curl -sS --compressed --connect-timeout %s --max-time %s '\
               '--capath %s --cert %s --cacert %s --key %s '\
-              '-H %s %s %s' % (100, 120,
+              '-H %s %s %s' % (config.Pilot.http_connect_timeout, config.Pilot.http_maxtime,
                                pipes.quote(_ctx.capath or ''), pipes.quote(_ctx.cacert or ''),
                                pipes.quote(_ctx.cacert or ''), pipes.quote(_ctx.cacert or ''),
                                pipes.quote('User-Agent: %s' % _ctx.user_agent),
